defmodule Op.Base do
  @moduledoc """
  The Base context.
  """

  import Ecto.Query, warn: false
  alias Op.Repo

  alias Op.Base.Queri

  @doc """
  Returns the list of queries.

  ## Examples

      iex> list_queries()
      [%Queri{}, ...]

  """
  def list_queries do
    Repo.all(Queri)
  end

  @doc """
  Gets a single queri.

  Raises `Ecto.NoResultsError` if the Queri does not exist.

  ## Examples

      iex> get_queri!(123)
      %Queri{}

      iex> get_queri!(456)
      ** (Ecto.NoResultsError)

  """
  def get_queri!(id), do: Repo.get!(Queri, id)

  @doc """
  Creates a queri.

  ## Examples

      iex> create_queri(%{field: value})
      {:ok, %Queri{}}

      iex> create_queri(%{field: bad_value})
      {:error, %Ecto.Changeset{}}

  """
  def create_queri(attrs \\ %{}) do
    %Queri{}
    |> Queri.changeset(attrs)
    |> Repo.insert()
  end

  @doc """
  Updates a queri.

  ## Examples

      iex> update_queri(queri, %{field: new_value})
      {:ok, %Queri{}}

      iex> update_queri(queri, %{field: bad_value})
      {:error, %Ecto.Changeset{}}

  """
  def update_queri(%Queri{} = queri, attrs) do
    queri
    |> Queri.changeset(attrs)
    |> Repo.update()
  end

  @doc """
  Deletes a queri.

  ## Examples

      iex> delete_queri(queri)
      {:ok, %Queri{}}

      iex> delete_queri(queri)
      {:error, %Ecto.Changeset{}}

  """
  def delete_queri(%Queri{} = queri) do
    Repo.delete(queri)
  end

  @doc """
  Returns an `%Ecto.Changeset{}` for tracking queri changes.

  ## Examples

      iex> change_queri(queri)
      %Ecto.Changeset{data: %Queri{}}

  """
  def change_queri(%Queri{} = queri, attrs \\ %{}) do
    Queri.changeset(queri, attrs)
  end
end
